<?php

/**
 * Implements hook_path_alias_types().
 */
function car_path_alias_types() {
  $objects['car/'] = t('Cars');
  return $objects;
}

/**
 * Implements hook_pathauto().
 */
function car_pathauto($op) {
  switch ($op) {
    case 'settings':
      $settings = array();
      $settings['module'] = 'car';
      $settings['token_type'] = 'car';
      $settings['groupheader'] = t('Car paths');
      $settings['patterndescr'] = t('Pattern for car page paths');
      $settings['patterndefault'] = 'cars/[car:name]';
      $settings['batch_update_callback'] = 'car_pathauto_bulk_update_batch_process';
      $settings['batch_file'] = drupal_get_path('module', 'car') . '/car.pathauto.inc';
      return (object) $settings;
    default:
      break;
  }
}

/**
 * Batch processing callback; Generate aliases for cars.
 */
function car_pathauto_bulk_update_batch_process(&$context) {
  if (!isset($context['sandbox']['current'])) {
    $context['sandbox']['count'] = 0;
    $context['sandbox']['current'] = 0;
  }

  $query = db_select('car', 'c');
  $query->leftJoin('url_alias', 'ua', "CONCAT('car/', c.cid) = ua.source");
  $query->addField('c', 'cid');
  $query->isNull('ua.source');
  $query->condition('c.cid', $context['sandbox']['current'], '>');
  $query->orderBy('c.cid');
  $query->addTag('pathauto_bulk_update');
  $query->addMetaData('entity', 'car');

  // Get the total amount of items to process.
  if (!isset($context['sandbox']['total'])) {
    $context['sandbox']['total'] = $query->countQuery()->execute()->fetchField();

    // If there are no nodes to update, the stop immediately.
    if (!$context['sandbox']['total']) {
      $context['finished'] = 1;
      return;
    }
  }

  $query->range(0, 25);
  $cids = $query->execute()->fetchCol();

  car_pathauto_car_update_alias_multiple($cids, 'bulkupdate');
  $context['sandbox']['count'] += count($cids);
  $context['sandbox']['current'] = max($cids);
  $context['message'] = t('Updated alias for car @cid.', array('@cid' => end($cids)));

  if ($context['sandbox']['count'] != $context['sandbox']['total']) {
    $context['finished'] = $context['sandbox']['count'] / $context['sandbox']['total'];
  }
}

/**
 * Update the URL aliases for an individual car.
 *
 * @param $car
 *   A car object.
 * @param $op
 *   Operation being performed on the car ('insert', 'update' or 'bulkupdate').
 * @param $options
 *   An optional array of additional options.
 */
function car_pathauto_car_update_alias($car, $op, array $options = array()) {
  // Skip processing if the user has disabled pathauto for the car.
  if (isset($car->path['pathauto']) && empty($car->path['pathauto'])) {
    return;
  }

  // Skip processing if the car has no pattern.
  if (!pathauto_pattern_load_by_entity('car')) {
    return;
  }

  module_load_include('inc', 'pathauto');
  $uri = entity_uri('car', $car);
  pathauto_create_alias('car', $op, $uri['path'], array('car' => $car));
}

/**
 * Update the URL aliases for multiple cars.
 *
 * @param $cids
 *   An array of car IDs.
 * @param $op
 *   Operation being performed on the cars ('insert', 'update' or 'bulkupdate').
 * @param $options
 *   An optional array of additional options.
 */
function car_pathauto_car_update_alias_multiple(array $cids, $op, array $options = array()) {
  $options += array('message' => FALSE);

  $cars = car_load_multiple($cids);
  foreach ($cars as $car) {
    car_pathauto_car_update_alias($car, $op, $options);
  }

  if (!empty($options['message'])) {
    drupal_set_message(format_plural(count($cars), 'Updated URL alias for 1 car.', 'Updated URL aliases for @count cars.'));
  }
}
