<?php

/**
 * @file
 * Token integration for the car module.
 */

/**
 * Implements hook_token_info().
 */
function car_token_info() {
  $info['types']['car'] = array(
    'name' => t('Cars'),
    'description' => t('Tokens related to individual cars.'),
    'needs-data' => 'car',
  );

  $info['tokens']['car']['cid'] = array(
    'name' => t('Car ID'),
    'description' => t('The unique ID of the car.'),
  );
  $info['tokens']['car']['name'] = array(
    'name' => t('Name'),
    'description' => t('The name of the car.'),
  );
  $info['tokens']['car']['url'] = array(
    'name' => t('URL'),
    'description' => t('The URL of the car.'),
    'type' => 'url',
  );
  $info['tokens']['car']['edit-url'] = array(
    'name' => t('Edit URL'),
    'description' => t("The URL of the car's edit page."),
  );
  $info['tokens']['car']['owner'] = array(
    'name' => t('Owner'),
    'description' => t('The owner of the car'),
    'type' => 'user',
  );

  return $info;
}

/**
 * Implements hook_tokens().
 */
function car_tokens($type, $tokens, array $data = array(), array $options = array()) {
  $replacements = array();

  $url_options = array('absolute' => TRUE);
  if (isset($options['language'])) {
    $url_options['language'] = $options['language'];
    $language_code = $options['language']->language;
  }
  else {
    $language_code = NULL;
  }

  $sanitize = !empty($options['sanitize']);

  if ($type == 'car' && !empty($data['car'])) {
    $car = $data['car'];

    foreach ($tokens as $name => $original) {
      switch ($name) {
        case 'cid':
          $replacements[$original] = $car->cid;
          break;
        case 'name':
          $name = entity_label('car', $car);
          $replacements[$original] = $sanitize ? check_plain($name) : $name;
          break;
        case 'owner':
          $account = user_load($car->uid);
          $name = format_username($account);
          $replacements[$original] = $sanitize ? check_plain($name) : $name;
          break;
        case 'url':
          $uri = entity_uri('car', $car);
          $replacements[$original] = url($uri['path'], $uri['options'] + $url_options);
          break;
        case 'edit-url':
          $replacements[$original] = url("car/{$car->cid}/edit", $url_options);
          break;
      }
    }

    // Chained token replacements.
    if ($owner_tokens = token_find_with_prefix($tokens, 'owner')) {
      $owner = user_load($car->uid);
      $replacements += token_generate('user', $owner_tokens, array('user' => $owner), $options);
    }
    if ($url_tokens = token_find_with_prefix($tokens, 'url')) {
      $uri = entity_uri('car', $car);
      $replacements += token_generate('url', $url_tokens, array('path' => $uri['path'], 'options' => $uri['options']), $options);
    }
  }

  return $replacements;
}
